%define anolis_release 7
Summary: Device-mapper Persistent Data Tools
Name: device-mapper-persistent-data
Version: 0.9.0
Release: %{anolis_release}%{?dist}
License: GPLv3+
URL: https://github.com/jthornber/thin-provisioning-tools
Source0: https://github.com/jthornber/thin-provisioning-tools/archive/v%{version}.tar.gz
# download by `cargo vendor --respect-source-config` after patches applied
# when update version, this vendor.tar.gz should update together
Source1: thin-provisioning-tools-vendor-%{version}.tar.gz
Patch0: device-mapper-persistent-data-avoid-strip.patch

# backport to fix build error
Patch1: 0001-Update-dependencies.patch
Patch2: 0001-all-Fix-resource-leaks.patch
Patch3: 0002-thin_show_metadata-Fix-out-of-bounds-access.patch
Patch4: 0003-build-Fix-customized-emitter-linkage.patch
Patch5: 0004-thin_dump-Fix-leaked-shared-object-handle.patch
Patch6: 0005-thin_show_duplicates-Fix-potential-errors.patch
Patch7: 0006-thin_metadata_size-Fix-potential-string-overflow.patch
Patch8: 0007-all-Fix-uninitialized-class-members.patch
Patch9: 0008-thin_dump-Fix-warnings-on-potential-NULL-pointer.patch
Patch10: 0009-build-Remove-unused-sources-from-the-regular-build.patch
Patch11: 0010-all-Remove-unreachable-code.patch
Patch12: 0011-file_utils-Fix-resource-leak.patch
Patch13: 0012-thin_delta-Clean-up-duplicated-code.patch
Patch14: 0013-build-Remove-lboost_iostreams-linker-flag.patch
Patch15: 0014-cargo-update.patch

BuildRequires: autoconf, expat-devel, libaio-devel, libstdc++-devel, boost-devel, gcc-c++
Requires: expat
%ifarch %{rust_arches}
BuildRequires: rust-packaging
BuildRequires: rust >= 1.35
BuildRequires: cargo
%endif
BuildRequires: make

%description
thin-provisioning-tools contains check,dump,restore,repair,rmap
and metadata_size tools to manage device-mapper thin provisioning
target metadata devices; cache check,dump,metadata_size,restore
and repair tools to manage device-mapper cache metadata devices
are included and era check, dump, restore and invalidate to manage
snapshot eras

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -q -n thin-provisioning-tools-%{version}
%ifarch %{rust_arches}
%patch1 -p1 -b .toml_update
%patch15 -p1 -b .backup15
tar xf %{SOURCE1}
mkdir -p .cargo
cat > .cargo/config <<END
[source.crates-io]
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "vendor"

END
%endif
%patch0 -p1 -b .avoid_strip
%patch2 -p1 -b .backup2
%patch3 -p1 -b .backup3
%patch4 -p1 -b .backup4
%patch5 -p1 -b .backup5
%patch6 -p1 -b .backup6
%patch7 -p1 -b .backup7
%patch8 -p1 -b .backup8
%patch9 -p1 -b .backup9
%patch10 -p1 -b .backup10
%patch11 -p1 -b .backup11
%patch12 -p1 -b .backup12
%patch13 -p1 -b .backup13
%patch14 -p1 -b .backup14
echo %{version}-%{release} > VERSION

%generate_buildrequires

%build
autoconf
%configure --with-optimisation=
make %{?_smp_mflags} V=
%ifarch %{rust_arches}
%cargo_build
%endif

%install
%make_install
%ifarch %{rust_arches}
%make_install install-rust-tools
%endif

%files
%doc COPYING
%{_mandir}/man8/cache_check.8*
%{_mandir}/man8/cache_dump.8*
%{_mandir}/man8/cache_metadata_size.8*
%{_mandir}/man8/cache_repair.8*
%{_mandir}/man8/cache_restore.8*
%{_mandir}/man8/cache_writeback.8*
%{_mandir}/man8/era_check.8*
%{_mandir}/man8/era_dump.8*
%{_mandir}/man8/era_invalidate.8*
%{_mandir}/man8/era_restore.8*
%{_mandir}/man8/thin_check.8*
%{_mandir}/man8/thin_delta.8*
%{_mandir}/man8/thin_dump.8*
%{_mandir}/man8/thin_ls.8*
%{_mandir}/man8/thin_metadata_size.8*
%{_mandir}/man8/thin_repair.8*
%{_mandir}/man8/thin_restore.8*
%{_mandir}/man8/thin_rmap.8*
%{_mandir}/man8/thin_trim.8*
%ifarch %{rust_arches}
%{_mandir}/man8/thin_metadata_pack.8*
%{_mandir}/man8/thin_metadata_unpack.8*
%endif
%{_sbindir}/pdata_tools
%{_sbindir}/cache_check
%{_sbindir}/cache_dump
%{_sbindir}/cache_metadata_size
%{_sbindir}/cache_repair
%{_sbindir}/cache_restore
%{_sbindir}/cache_writeback
%{_sbindir}/era_check
%{_sbindir}/era_dump
%{_sbindir}/era_invalidate
%{_sbindir}/era_restore
%{_sbindir}/thin_check
%{_sbindir}/thin_delta
%{_sbindir}/thin_dump
%{_sbindir}/thin_ls
%{_sbindir}/thin_metadata_size
%{_sbindir}/thin_repair
%{_sbindir}/thin_restore
%{_sbindir}/thin_rmap
%{_sbindir}/thin_trim
%ifarch %{rust_arches}
%{_sbindir}/thin_metadata_pack
%{_sbindir}/thin_metadata_unpack
%endif

%files doc
%doc README.md

%changelog
* Thu Dec 22 2022 Funda Wang <fundawang@yeah.net> - 0.9.0-7
- Bump release for upgrading from anolis 8

* Mon Oct 10 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.9.0-3
- add doc package

* Thu Jun 9 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.9.0-2
- add cargo vendor files to make sure rust build

* Fri Mar 11 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.9.0-1
- Init from  upstream version 0.9.0
